@@ -9,9 +9,10 @@ import (
 )
 
 type EFSMountTarget struct {
-	svc  *efs.EFS
-	id   string
-	fsid string
+	svc    *efs.EFS
+	id     string
+	fsid   string
+	fsTags []*efs.Tag
 }
 
 func init() {
@@ -31,16 +32,21 @@ func ListEFSMountTargets(sess *session.Session) ([]Resource, error) {
 		mt, err := svc.DescribeMountTargets(&efs.DescribeMountTargetsInput{
 			FileSystemId: fs.FileSystemId,
 		})
+		if err != nil {
+			return nil, err
+		}
 
+		lto, err := svc.ListTagsForResource(&efs.ListTagsForResourceInput{ResourceId: fs.FileSystemId})
 		if err != nil {
 			return nil, err
 		}
 
 		for _, t := range mt.MountTargets {
 			resources = append(resources, &EFSMountTarget{
-				svc:  svc,
-				id:   *t.MountTargetId,
-				fsid: *t.FileSystemId,
+				svc:    svc,
+				id:     *t.MountTargetId,
+				fsid:   *t.FileSystemId,
+				fsTags: lto.Tags,
 			})
 
 		}
@@ -58,9 +64,13 @@ func (e *EFSMountTarget) Remove() error {
 }
 
 func (e *EFSMountTarget) Properties() types.Properties {
-	return types.NewProperties().
-		Set("Name", e.id).
-		Set("ID", e.fsid)
+	properties := types.NewProperties()
+	for _, tagValue := range e.fsTags {
+		properties.SetTagWithPrefix("efs", tagValue.Key, tagValue.Value)
+	}
+	properties.Set("Name", e.id)
+	properties.Set("ID", e.fsid)
+	return properties
 }
 
 func (e *EFSMountTarget) String() string {
